[llvm-branch-commits] [cfe-branch] r214746 - Merging r214119:

2014-08-04 Thread Bill Wendling
Author: void
Date: Mon Aug  4 13:34:05 2014
New Revision: 214746

URL: http://llvm.org/viewvc/llvm-project?rev=214746view=rev
Log:
Merging r214119:

r214119 | joerg | 2014-07-28 14:06:22 -0700 (Mon, 28 Jul 2014) | 7 lines

Change __INTx_TYPE__ to be always signed. This changes the value for
char-based types from char to signed char. Adjust stdint.h to use
__INTx_TYPE__ directly without prefixing it with signed and to use
__UINTx_TYPE__ for unsigned ones.

The value of __INTx_TYPE__ now matches GCC.



Modified:
cfe/branches/release_35/   (props changed)
cfe/branches/release_35/lib/Basic/TargetInfo.cpp
cfe/branches/release_35/lib/Headers/stdint.h
cfe/branches/release_35/test/Preprocessor/init.c
cfe/branches/release_35/test/Preprocessor/stdint.c

Propchange: cfe/branches/release_35/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Aug  4 13:34:05 2014
@@ -1,4 +1,4 @@
 /cfe/branches/type-system-rewrite:134693-134817
-/cfe/trunk:213609,213611,213613,213741,213840,213902,213912,213993,213998,214008,214050,214208,214222,214369,214390,214471
+/cfe/trunk:213609,213611,213613,213741,213840,213902,213912,213993,213998,214008,214050,214119,214208,214222,214369,214390,214471
 /cfe/trunk/test:170344
 /cfe/trunk/test/SemaTemplate:126920

Modified: cfe/branches/release_35/lib/Basic/TargetInfo.cpp
URL: 
http://llvm.org/viewvc/llvm-project/cfe/branches/release_35/lib/Basic/TargetInfo.cpp?rev=214746r1=214745r2=214746view=diff
==
--- cfe/branches/release_35/lib/Basic/TargetInfo.cpp (original)
+++ cfe/branches/release_35/lib/Basic/TargetInfo.cpp Mon Aug  4 13:34:05 2014
@@ -103,7 +103,7 @@ TargetInfo::~TargetInfo() {}
 const char *TargetInfo::getTypeName(IntType T) {
   switch (T) {
   default: llvm_unreachable(not an integer!);
-  case SignedChar:   return char;
+  case SignedChar:   return signed char;
   case UnsignedChar: return unsigned char;
   case SignedShort:  return short;
   case UnsignedShort:return unsigned short;

Modified: cfe/branches/release_35/lib/Headers/stdint.h
URL: 
http://llvm.org/viewvc/llvm-project/cfe/branches/release_35/lib/Headers/stdint.h?rev=214746r1=214745r2=214746view=diff
==
--- cfe/branches/release_35/lib/Headers/stdint.h (original)
+++ cfe/branches/release_35/lib/Headers/stdint.h Mon Aug  4 13:34:05 2014
@@ -104,9 +104,9 @@
 
 #ifdef __INT64_TYPE__
 # ifndef __int8_t_defined /* glibc sys/types.h also defines int64_t*/
-typedef signed __INT64_TYPE__ int64_t;
+typedef __INT64_TYPE__ int64_t;
 # endif /* __int8_t_defined */
-typedef unsigned __INT64_TYPE__ uint64_t;
+typedef __UINT64_TYPE__ uint64_t;
 # define __int_least64_t int64_t
 # define __uint_least64_t uint64_t
 # define __int_least32_t int64_t
@@ -125,8 +125,8 @@ typedef __uint_least64_t uint_fast64_t;
 #endif /* __int_least64_t */
 
 #ifdef __INT56_TYPE__
-typedef signed __INT56_TYPE__ int56_t;
-typedef unsigned __INT56_TYPE__ uint56_t;
+typedef __INT56_TYPE__ int56_t;
+typedef __UINT56_TYPE__ uint56_t;
 typedef int56_t int_least56_t;
 typedef uint56_t uint_least56_t;
 typedef int56_t int_fast56_t;
@@ -141,8 +141,8 @@ typedef uint56_t uint_fast56_t;
 
 
 #ifdef __INT48_TYPE__
-typedef signed __INT48_TYPE__ int48_t;
-typedef unsigned __INT48_TYPE__ uint48_t;
+typedef __INT48_TYPE__ int48_t;
+typedef __UINT48_TYPE__ uint48_t;
 typedef int48_t int_least48_t;
 typedef uint48_t uint_least48_t;
 typedef int48_t int_fast48_t;
@@ -157,8 +157,8 @@ typedef uint48_t uint_fast48_t;
 
 
 #ifdef __INT40_TYPE__
-typedef signed __INT40_TYPE__ int40_t;
-typedef unsigned __INT40_TYPE__ uint40_t;
+typedef __INT40_TYPE__ int40_t;
+typedef __UINT40_TYPE__ uint40_t;
 typedef int40_t int_least40_t;
 typedef uint40_t uint_least40_t;
 typedef int40_t int_fast40_t;
@@ -175,12 +175,12 @@ typedef uint40_t uint_fast40_t;
 #ifdef __INT32_TYPE__
 
 # ifndef __int8_t_defined /* glibc sys/types.h also defines int32_t*/
-typedef signed __INT32_TYPE__ int32_t;
+typedef __INT32_TYPE__ int32_t;
 # endif /* __int8_t_defined */
 
 # ifndef __uint32_t_defined  /* more glibc compatibility */
 # define __uint32_t_defined
-typedef unsigned __INT32_TYPE__ uint32_t;
+typedef __UINT32_TYPE__ uint32_t;
 # endif /* __uint32_t_defined */
 
 # define __int_least32_t int32_t
@@ -199,8 +199,8 @@ typedef __uint_least32_t uint_fast32_t;
 #endif /* __int_least32_t */
 
 #ifdef __INT24_TYPE__
-typedef signed __INT24_TYPE__ int24_t;
-typedef unsigned __INT24_TYPE__ uint24_t;
+typedef __INT24_TYPE__ int24_t;
+typedef __UINT24_TYPE__ uint24_t;
 typedef int24_t int_least24_t;
 typedef uint24_t uint_least24_t;
 typedef int24_t int_fast24_t;
@@ -213,9 +213,9 @@ typedef uint24_t 

[llvm-branch-commits] [cfe-branch] r214748 - Merging r213999:

2014-08-04 Thread Bill Wendling
Author: void
Date: Mon Aug  4 13:36:16 2014
New Revision: 214748

URL: http://llvm.org/viewvc/llvm-project?rev=214748view=rev
Log:
Merging r213999:

r213999 | tstellar | 2014-07-25 18:05:20 -0700 (Fri, 25 Jul 2014) | 1 line

R600: Add processor type for Mullins


Modified:
cfe/branches/release_35/   (props changed)
cfe/branches/release_35/lib/Basic/Targets.cpp
cfe/branches/release_35/test/Driver/r600-mcpu.cl

Propchange: cfe/branches/release_35/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Aug  4 13:36:16 2014
@@ -1,4 +1,4 @@
 /cfe/branches/type-system-rewrite:134693-134817
-/cfe/trunk:213609,213611,213613,213741,213840,213902,213912,213993,213998,214008,214050,214119,214208,214222,214369,214390,214471
+/cfe/trunk:213609,213611,213613,213741,213840,213902,213912,213993,213998-213999,214008,214050,214119,214208,214222,214369,214390,214471
 /cfe/trunk/test:170344
 /cfe/trunk/test/SemaTemplate:126920

Modified: cfe/branches/release_35/lib/Basic/Targets.cpp
URL: 
http://llvm.org/viewvc/llvm-project/cfe/branches/release_35/lib/Basic/Targets.cpp?rev=214748r1=214747r2=214748view=diff
==
--- cfe/branches/release_35/lib/Basic/Targets.cpp (original)
+++ cfe/branches/release_35/lib/Basic/Targets.cpp Mon Aug  4 13:36:16 2014
@@ -1566,6 +1566,7 @@ public:
   .Case(kabini,   GK_SEA_ISLANDS)
   .Case(kaveri,   GK_SEA_ISLANDS)
   .Case(hawaii,   GK_SEA_ISLANDS)
+  .Case(mullins,  GK_SEA_ISLANDS)
   .Default(GK_NONE);
 
 if (GPU == GK_NONE) {

Modified: cfe/branches/release_35/test/Driver/r600-mcpu.cl
URL: 
http://llvm.org/viewvc/llvm-project/cfe/branches/release_35/test/Driver/r600-mcpu.cl?rev=214748r1=214747r2=214748view=diff
==
--- cfe/branches/release_35/test/Driver/r600-mcpu.cl (original)
+++ cfe/branches/release_35/test/Driver/r600-mcpu.cl Mon Aug  4 13:36:16 2014
@@ -34,6 +34,7 @@
 // RUN: %clang -### -target r600 -x cl -S -emit-llvm -mcpu=kabini %s -o - 21 
| FileCheck --check-prefix=KABINI-CHECK %s
 // RUN: %clang -### -target r600 -x cl -S -emit-llvm -mcpu=kaveri %s -o - 21 
| FileCheck --check-prefix=KAVERI-CHECK %s
 // RUN: %clang -### -target r600 -x cl -S -emit-llvm -mcpu=hawaii %s -o - 21 
| FileCheck --check-prefix=HAWAII-CHECK %s
+// RUN: %clang -### -target r600 -x cl -S -emit-llvm -mcpu=mullins %s -o - 
21 | FileCheck --check-prefix=MULLINS-CHECK %s
 
 // R600-CHECK:  -target-cpu r600
 // RS880-CHECK: -target-cpu rs880
@@ -58,3 +59,4 @@
 // KABINI-CHECK: -target-cpu kabini
 // KAVERI-CHECK: -target-cpu kaveri
 // HAWAII-CHECK: -target-cpu hawaii
+// MULLINS-CHECK: -target-cpu mullins


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [cfe-branch] r214750 - Merging r213913:

2014-08-04 Thread Bill Wendling
Author: void
Date: Mon Aug  4 13:37:31 2014
New Revision: 214750

URL: http://llvm.org/viewvc/llvm-project?rev=214750view=rev
Log:
Merging r213913:

r213913 | rsmith | 2014-07-24 18:12:44 -0700 (Thu, 24 Jul 2014) | 4 lines

PR20445: Properly transform the initializer in a CXXNewExpr rather than running
it through the normal TreeTransform logic for Exprs (which will strip off
implicit parts of the initialization and never re-create them).



Modified:
cfe/branches/release_35/   (props changed)
cfe/branches/release_35/lib/Sema/SemaExprCXX.cpp
cfe/branches/release_35/lib/Sema/TreeTransform.h

cfe/branches/release_35/test/CodeGenCXX/cxx0x-initializer-stdinitializerlist.cpp

Propchange: cfe/branches/release_35/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Aug  4 13:37:31 2014
@@ -1,4 +1,4 @@
 /cfe/branches/type-system-rewrite:134693-134817
-/cfe/trunk:213609,213611,213613,213741,213840,213902,213912,213993,213998-213999,214008,214050,214119,214208,214222,214369,214390,214471
+/cfe/trunk:213609,213611,213613,213741,213840,213902,213912-213913,213993,213998-213999,214008,214050,214119,214208,214222,214369,214390,214471
 /cfe/trunk/test:170344
 /cfe/trunk/test/SemaTemplate:126920

Modified: cfe/branches/release_35/lib/Sema/SemaExprCXX.cpp
URL: 
http://llvm.org/viewvc/llvm-project/cfe/branches/release_35/lib/Sema/SemaExprCXX.cpp?rev=214750r1=214749r2=214750view=diff
==
--- cfe/branches/release_35/lib/Sema/SemaExprCXX.cpp (original)
+++ cfe/branches/release_35/lib/Sema/SemaExprCXX.cpp Mon Aug  4 13:37:31 2014
@@ -1184,14 +1184,6 @@ Sema::BuildCXXNew(SourceRange Range, boo
 NumInits = List-getNumExprs();
   }
 
-  // Determine whether we've already built the initializer.
-  bool HaveCompleteInit = false;
-  if (Initializer  isaCXXConstructExpr(Initializer) 
-  !isaCXXTemporaryObjectExpr(Initializer))
-HaveCompleteInit = true;
-  else if (Initializer  isaImplicitValueInitExpr(Initializer))
-HaveCompleteInit = true;
-
   // C++11 [dcl.spec.auto]p6. Deduce the type which 'auto' stands in for.
   if (TypeMayContainAuto  AllocType-isUndeducedType()) {
 if (initStyle == CXXNewExpr::NoInit || NumInits == 0)
@@ -1481,8 +1473,7 @@ Sema::BuildCXXNew(SourceRange Range, boo
   // do it now.
   if (!AllocType-isDependentType() 
   !Expr::hasAnyTypeDependentArguments(
-llvm::makeArrayRef(Inits, NumInits)) 
-  !HaveCompleteInit) {
+  llvm::makeArrayRef(Inits, NumInits))) {
 // C++11 [expr.new]p15:
 //   A new-expression that creates an object of type T initializes that
 //   object as follows:

Modified: cfe/branches/release_35/lib/Sema/TreeTransform.h
URL: 
http://llvm.org/viewvc/llvm-project/cfe/branches/release_35/lib/Sema/TreeTransform.h?rev=214750r1=214749r2=214750view=diff
==
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Aug  4 14:58:38 2014
@@ -1,4 +1,4 @@
 /cfe/branches/type-system-rewrite:134693-134817
-/cfe/trunk:213609,213611,213613,213741,213834,213840,213902,213912-213913,213993,213998-213999,214008,214050,214119,214208,214222,214369,214390,214471
+/cfe/trunk:213609,213611,213613,213741,213834,213840,213902,213912-213913,213993,213998-213999,214008,214050,214060,214119,214208,214222,214369,214390,214471
 /cfe/trunk/test:170344
 /cfe/trunk/test/SemaTemplate:126920

Modified: cfe/branches/release_35/lib/Driver/ToolChains.h
URL: 
http://llvm.org/viewvc/llvm-project/cfe/branches/release_35/lib/Driver/ToolChains.h?rev=214765r1=214764r2=214765view=diff
==
--- cfe/branches/release_35/lib/Driver/ToolChains.h (original)
+++ cfe/branches/release_35/lib/Driver/ToolChains.h Mon Aug  4 14:58:38 2014
@@ -542,7 +542,7 @@ public:
 return 2;
   }
 
-  virtual bool IsIntegratedAssemblerDefault() const {
+  virtual bool IsIntegratedAssemblerDefault() const override {
 if (getTriple().getArch() == llvm::Triple::ppc ||
 getTriple().getArch() == llvm::Triple::sparc ||
 getTriple().getArch() == llvm::Triple::sparcv9)


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [llvm-branch] r214764 - Merging r214060:

2014-08-04 Thread Bill Wendling
Author: void
Date: Mon Aug  4 14:58:16 2014
New Revision: 214764

URL: http://llvm.org/viewvc/llvm-project?rev=214764view=rev
Log:
Merging r214060:


Modified:
llvm/branches/release_35/   (props changed)

Propchange: llvm/branches/release_35/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Aug  4 14:58:16 2014
@@ -1,3 +1,3 @@
 /llvm/branches/Apple/Pertwee:110850,110961
 /llvm/branches/type-system-rewrite:133420-134817
-/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214129,214180,214287,214331,214423,214429,214519
+/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214060,214129,214180,214287,214331,214423,214429,214519


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [lldb] r214766 - Merging r214291:

2014-08-04 Thread Bill Wendling
Author: void
Date: Mon Aug  4 15:01:31 2014
New Revision: 214766

URL: http://llvm.org/viewvc/llvm-project?rev=214766view=rev
Log:
Merging r214291:

r214291 | sylvestre | 2014-07-30 01:33:21 -0700 (Wed, 30 Jul 2014) | 11 lines

Use __linux__ macro throughout, instead of ocasional __linux.

__linux is not universally defined across all standards versions, compilers and 
architectures. Specifically at C99 and up, it's not defined in GCC on powerpc 
platform.

See https://gcc.gnu.org/bugzilla/show_bug.cgi?id=28314

Bugzilla: http://llvm.org/bugs/show_bug.cgi?id=20380

Patch by Dimitri John Ledkov dimitri.led...@canonical.com




Modified:
lldb/branches/release_35/   (props changed)
lldb/branches/release_35/tools/lldb-mi/MICmnLogMediumFile.cpp
lldb/branches/release_35/tools/lldb-mi/MIUtilSystemLinux.cpp
lldb/branches/release_35/tools/lldb-mi/MIUtilSystemLinux.h

Propchange: lldb/branches/release_35/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Aug  4 15:01:31 2014
@@ -1,2 +1,3 @@
 /lldb/branches/apple/python-GIL:156467-162159
 /lldb/branches/iohandler:198360-200250
+/lldb/trunk:214291

Modified: lldb/branches/release_35/tools/lldb-mi/MICmnLogMediumFile.cpp
URL: 
http://llvm.org/viewvc/llvm-project/lldb/branches/release_35/tools/lldb-mi/MICmnLogMediumFile.cpp?rev=214766r1=214765r2=214766view=diff
==
--- lldb/branches/release_35/tools/lldb-mi/MICmnLogMediumFile.cpp (original)
+++ lldb/branches/release_35/tools/lldb-mi/MICmnLogMediumFile.cpp Mon Aug  4 
15:01:31 2014
@@ -28,7 +28,7 @@
 
 #if defined( _MSC_VER )
#include MIUtilSystemWindows.h
-#elif defined( __FreeBSD__ ) || defined( __linux )
+#elif defined( __FreeBSD__ ) || defined( __linux__ )
#include MIUtilSystemLinux.h
 #elif defined( __APPLE__ )
#include MIUtilSystemOsx.h

Modified: lldb/branches/release_35/tools/lldb-mi/MIUtilSystemLinux.cpp
URL: 
http://llvm.org/viewvc/llvm-project/lldb/branches/release_35/tools/lldb-mi/MIUtilSystemLinux.cpp?rev=214766r1=214765r2=214766view=diff
==
--- lldb/branches/release_35/tools/lldb-mi/MIUtilSystemLinux.cpp (original)
+++ lldb/branches/release_35/tools/lldb-mi/MIUtilSystemLinux.cpp Mon Aug  4 
15:01:31 2014
@@ -22,7 +22,7 @@
 // Include compiler configuration
 #include MICmnConfig.h
 
-#if defined( __FreeBSD__ ) || defined( __linux )
+#if defined( __FreeBSD__ ) || defined( __linux__ )
 
 // In-house headers:
 #include MIUtilSystemLinux.h
@@ -119,4 +119,4 @@ bool CMIUtilSystemLinux::GetLogFilesPath
return MIstatus::success;
 }
 
-#endif // #if defined( __linux )
+#endif // #if defined( __linux__ )

Modified: lldb/branches/release_35/tools/lldb-mi/MIUtilSystemLinux.h
URL: 
http://llvm.org/viewvc/llvm-project/lldb/branches/release_35/tools/lldb-mi/MIUtilSystemLinux.h?rev=214766r1=214765r2=214766view=diff
==
--- lldb/branches/release_35/tools/lldb-mi/MIUtilSystemLinux.h (original)
+++ lldb/branches/release_35/tools/lldb-mi/MIUtilSystemLinux.h Mon Aug  4 
15:01:31 2014
@@ -24,7 +24,7 @@
 // Include compiler configuration
 #include MICmnConfig.h
 
-#if defined( __FreeBSD__ ) || defined( __linux )
+#if defined( __FreeBSD__ ) || defined( __linux__ )
 
 // In-house headers:
 #include MIUtilString.h  
@@ -57,4 +57,4 @@ public:
 
 typedef CMIUtilSystemLinux CMIUtilSystem;
 
-#endif // #if defined( __linux )
+#endif // #if defined( __linux__ )


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


Re: [llvm-branch-commits] [cfe-branch] r214778 - Merging r214777:

2014-08-04 Thread Bill Wendling
On Aug 4, 2014, at 2:29 PM, Hans Wennborg h...@chromium.org wrote:

 On Mon, Aug 4, 2014 at 2:11 PM, Hans Wennborg h...@hanshq.net wrote:
 Author: hans
 Date: Mon Aug  4 16:11:53 2014
 New Revision: 214778
 
 URL: http://llvm.org/viewvc/llvm-project?rev=214778view=rev
 Log:
 Merging r214777:
 
 Excluding the /Zp option, because that was added after the 3.5 branch.
 
 
 r214777 | hans | 2014-08-04 14:07:58 -0700 (Mon, 04 Aug 2014) | 1 line
 
 UsersManual: update clang-cl options
 
 
 Modified:
cfe/branches/release_35/   (props changed)
cfe/branches/release_35/docs/UsersManual.rst

 cfe/branches/release_35/test/Analysis/MismatchedDeallocator-checker-test.mm  
  (props changed)
cfe/branches/release_35/test/Analysis/NewDelete-checker-test.cpp   (props 
 changed)
cfe/branches/release_35/test/SemaCXX/warn-unreachable.cpp   (props 
 changed)
 
 Weird.. I have no idea why it committed props changes to files in
 test/, that was certainly not my intention.
 
 Since it's just metadata, maybe I can treat it as benign, or do you
 think I should try to revert that part of the commit?

This happens all the time with ‘svn merge’. It’s a mystery to me. You can 
ignore it (I do :-).

-bw


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [cfe-branch] r214839 - Merging r214734:

2014-08-04 Thread Bill Wendling
Author: void
Date: Tue Aug  5 00:19:17 2014
New Revision: 214839

URL: http://llvm.org/viewvc/llvm-project?rev=214839view=rev
Log:
Merging r214734:

r214734 | ogoffart | 2014-08-04 10:28:05 -0700 (Mon, 04 Aug 2014) | 7 lines

Fix crash when assiging to a property with an invalid type

This is a regression from clang 3.4

Set the result to ExprError and returns true, rather than simply
returns false because errors have been reported already and returning
false show a confusing error


Added:
cfe/branches/release_35/test/SemaObjCXX/property-invalid-type.mm
  - copied unchanged from r214734, 
cfe/trunk/test/SemaObjCXX/property-invalid-type.mm
Modified:
cfe/branches/release_35/   (props changed)
cfe/branches/release_35/lib/Sema/SemaPseudoObject.cpp

Propchange: cfe/branches/release_35/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Tue Aug  5 00:19:17 2014
@@ -1,4 +1,4 @@
 /cfe/branches/type-system-rewrite:134693-134817
-/cfe/trunk:213609,213611,213613,213741,213834,213840,213902,213912-213913,213993,213998-213999,214008,214050,214060,214119,214208,214222,214369,214390,214471,214777
+/cfe/trunk:213609,213611,213613,213741,213834,213840,213902,213912-213913,213993,213998-213999,214008,214050,214060,214119,214208,214222,214369,214390,214471,214734,214777
 /cfe/trunk/test:170344
 /cfe/trunk/test/SemaTemplate:126920

Modified: cfe/branches/release_35/lib/Sema/SemaPseudoObject.cpp
URL: 
http://llvm.org/viewvc/llvm-project/cfe/branches/release_35/lib/Sema/SemaPseudoObject.cpp?rev=214839r1=214838r2=214839view=diff
==
--- cfe/branches/release_35/lib/Sema/SemaPseudoObject.cpp (original)
+++ cfe/branches/release_35/lib/Sema/SemaPseudoObject.cpp Tue Aug  5 00:19:17 
2014
@@ -845,7 +845,12 @@ bool ObjCPropertyOpBuilder::tryBuildGetO
   if (!S.getLangOpts().CPlusPlus) return false;
 
   findGetter();
-  assert(Getter  property has no setter and no getter!);
+  if (!Getter) {
+// The property has no setter and no getter! This can happen if the type is
+// invalid. Error have already been reported.
+result = ExprError();
+return true;
+  }
 
   // Only do this if the getter returns an l-value reference type.
   QualType resultType = Getter-getReturnType();


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [cfe-branch] r214840 - Merging r214735:

2014-08-04 Thread Bill Wendling
Author: void
Date: Tue Aug  5 00:19:37 2014
New Revision: 214840

URL: http://llvm.org/viewvc/llvm-project?rev=214840view=rev
Log:
Merging r214735:

r214735 | ogoffart | 2014-08-04 10:28:11 -0700 (Mon, 04 Aug 2014) | 1 line

Fix crash when accessing a property of an invalid interface


Modified:
cfe/branches/release_35/   (props changed)
cfe/branches/release_35/lib/Sema/SemaPseudoObject.cpp
cfe/branches/release_35/test/SemaObjCXX/property-invalid-type.mm

Propchange: cfe/branches/release_35/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Tue Aug  5 00:19:37 2014
@@ -1,4 +1,4 @@
 /cfe/branches/type-system-rewrite:134693-134817
-/cfe/trunk:213609,213611,213613,213741,213834,213840,213902,213912-213913,213993,213998-213999,214008,214050,214060,214119,214208,214222,214369,214390,214471,214734,214777
+/cfe/trunk:213609,213611,213613,213741,213834,213840,213902,213912-213913,213993,213998-213999,214008,214050,214060,214119,214208,214222,214369,214390,214471,214734-214735,214777
 /cfe/trunk/test:170344
 /cfe/trunk/test/SemaTemplate:126920

Modified: cfe/branches/release_35/lib/Sema/SemaPseudoObject.cpp
URL: 
http://llvm.org/viewvc/llvm-project/cfe/branches/release_35/lib/Sema/SemaPseudoObject.cpp?rev=214840r1=214839r2=214840view=diff
==
--- cfe/branches/release_35/lib/Sema/SemaPseudoObject.cpp (original)
+++ cfe/branches/release_35/lib/Sema/SemaPseudoObject.cpp Tue Aug  5 00:19:37 
2014
@@ -284,7 +284,7 @@ namespace {
 bool tryBuildGetOfReference(Expr *op, ExprResult result);
 bool findSetter(bool warn=true);
 bool findGetter();
-bool DiagnoseUnsupportedPropertyUse();
+void DiagnoseUnsupportedPropertyUse();
 
 Expr *rebuildAndCaptureObject(Expr *syntacticBase) override;
 ExprResult buildGet() override;
@@ -642,7 +642,7 @@ bool ObjCPropertyOpBuilder::findSetter(b
   return false;
 }
 
-bool ObjCPropertyOpBuilder::DiagnoseUnsupportedPropertyUse() {
+void ObjCPropertyOpBuilder::DiagnoseUnsupportedPropertyUse() {
   if (S.getCurLexicalContext()-isObjCContainer() 
   S.getCurLexicalContext()-getDeclKind() != Decl::ObjCCategoryImpl 
   S.getCurLexicalContext()-getDeclKind() != Decl::ObjCImplementation) {
@@ -650,10 +650,8 @@ bool ObjCPropertyOpBuilder::DiagnoseUnsu
 S.Diag(RefExpr-getLocation(),
diag::err_property_function_in_objc_container);
 S.Diag(prop-getLocation(), diag::note_property_declare);
-return true;
 }
   }
-  return false;
 }
 
 /// Capture the base object of an Objective-C property expression.
@@ -679,10 +677,10 @@ Expr *ObjCPropertyOpBuilder::rebuildAndC
 /// Load from an Objective-C property reference.
 ExprResult ObjCPropertyOpBuilder::buildGet() {
   findGetter();
-  if (!Getter  DiagnoseUnsupportedPropertyUse())
-  return ExprError();
-
-  assert(Getter);
+  if (!Getter) {
+DiagnoseUnsupportedPropertyUse();
+return ExprError();
+  }
 
   if (SyntacticRefExpr)
 SyntacticRefExpr-setIsMessagingGetter();
@@ -720,10 +718,10 @@ ExprResult ObjCPropertyOpBuilder::buildG
 ///   value being set as the value of the property operation.
 ExprResult ObjCPropertyOpBuilder::buildSet(Expr *op, SourceLocation opcLoc,
bool captureSetValueAsResult) {
-  bool hasSetter = findSetter(false);
-  if (!hasSetter  DiagnoseUnsupportedPropertyUse())
-  return ExprError();
-  assert(hasSetter); (void) hasSetter;
+  if (!findSetter(false)) {
+DiagnoseUnsupportedPropertyUse();
+return ExprError();
+  }
 
   if (SyntacticRefExpr)
 SyntacticRefExpr-setIsMessagingSetter();

Modified: cfe/branches/release_35/test/SemaObjCXX/property-invalid-type.mm
URL: 
http://llvm.org/viewvc/llvm-project/cfe/branches/release_35/test/SemaObjCXX/property-invalid-type.mm?rev=214840r1=214839r2=214840view=diff
==
--- cfe/branches/release_35/test/SemaObjCXX/property-invalid-type.mm (original)
+++ cfe/branches/release_35/test/SemaObjCXX/property-invalid-type.mm Tue Aug  5 
00:19:37 2014
@@ -7,6 +7,7 @@
 @end
 @interface I ()
 @property A* response;  // expected-error {{unknown type name 'A'}}
+@property  int helper;
 @end
 @implementation I
 @synthesize response;
@@ -16,4 +17,7 @@
 }
 @end
 
-
+void foo(I *i)
+{
+  i.helper;
+}


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [llvm-branch] r214842 - Add blurb about LDC.

2014-08-04 Thread Bill Wendling
Author: void
Date: Tue Aug  5 00:23:26 2014
New Revision: 214842

URL: http://llvm.org/viewvc/llvm-project?rev=214842view=rev
Log:
Add blurb about LDC.

Modified:
llvm/branches/release_35/docs/ReleaseNotes.rst

Modified: llvm/branches/release_35/docs/ReleaseNotes.rst
URL: 
http://llvm.org/viewvc/llvm-project/llvm/branches/release_35/docs/ReleaseNotes.rst?rev=214842r1=214841r2=214842view=diff
==
--- llvm/branches/release_35/docs/ReleaseNotes.rst (original)
+++ llvm/branches/release_35/docs/ReleaseNotes.rst Tue Aug  5 00:23:26 2014
@@ -252,6 +252,19 @@ An exciting aspect of LLVM is that it is
 a lot of other language and tools projects. This section lists some of the
 projects that have already been updated to work with LLVM 3.5.
 
+LDC - the LLVM-based D compiler
+---
+
+`D http://dlang.org`_ is a language with C-like syntax and static typing. It
+pragmatically combines efficiency, control, and modeling power, with safety and
+programmer productivity. D supports powerful concepts like Compile-Time 
Function
+Execution (CTFE) and Template Meta-Programming, provides an innovative approach
+to concurrency and offers many classical paradigms.
+
+`LDC http://wiki.dlang.org/LDC`_ uses the frontend from the reference 
compiler
+combined with LLVM as backend to produce efficient native code. LDC targets
+x86/x86_64 systems like Linux, OS X, FreeBSD and Windows and also Linux/PPC64.
+Ports to other architectures like ARM, AArch64 and MIPS64 are underway.
 
 Additional Information
 ==


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [llvm-branch] r215001 - Renaming to coincide with updated tagging system.

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 18:13:41 2014
New Revision: 215001

URL: http://llvm.org/viewvc/llvm-project?rev=215001view=rev
Log:
Renaming to coincide with updated tagging system.

Added:
llvm/branches/release_350/   (props changed)
  - copied from r215000, llvm/branches/release_35/
Removed:
llvm/branches/release_35/

Propchange: llvm/branches/release_350/
--
--- svn:ignore (added)
+++ svn:ignore Wed Aug  6 18:13:41 2014
@@ -0,0 +1,24 @@
+Debug
+Release
+Release-Asserts
+mklib
+Makefile.config
+config.log
+config.status
+cvs.out
+autom4te.cache
+configure.out
+LLVM-*
+_distcheckdir
+llvm.spec
+svn-commit.*
+*.patch
+*.patch.raw
+cscope.*
+Debug+Coverage-Asserts
+Release+Coverage-Asserts
+Debug+Coverage
+Release+Coverage
+Debug+Checks
+Debug+Asserts
+Release+Asserts

Propchange: llvm/branches/release_350/
--
--- svn:mergeinfo (added)
+++ svn:mergeinfo Wed Aug  6 18:13:41 2014
@@ -0,0 +1,3 @@
+/llvm/branches/Apple/Pertwee:110850,110961
+/llvm/branches/type-system-rewrite:133420-134817
+/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798-213799,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214060,214129,214180,214287,214331,214423,214429,214519


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [compiler-rt-branch] r215005 - Renaming to coincide with updated tagging system.

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 18:13:55 2014
New Revision: 215005

URL: http://llvm.org/viewvc/llvm-project?rev=215005view=rev
Log:
Renaming to coincide with updated tagging system.

Added:
compiler-rt/branches/release_350/
  - copied from r215004, compiler-rt/branches/release_35/
Removed:
compiler-rt/branches/release_35/

___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [clang-tools-extra-branch] r215007 - Renaming to coincide with updated tagging system.

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 18:14:02 2014
New Revision: 215007

URL: http://llvm.org/viewvc/llvm-project?rev=215007view=rev
Log:
Renaming to coincide with updated tagging system.

Added:
clang-tools-extra/branches/release_350/
  - copied from r215006, clang-tools-extra/branches/release_35/
Removed:
clang-tools-extra/branches/release_35/

___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [polly] r215008 - Renaming to coincide with updated tagging system.

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 18:14:06 2014
New Revision: 215008

URL: http://llvm.org/viewvc/llvm-project?rev=215008view=rev
Log:
Renaming to coincide with updated tagging system.

Added:
polly/branches/release_350/
  - copied from r215007, polly/branches/release_35/
Removed:
polly/branches/release_35/

___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [lldb] r215019 - Revert renaming. Should rename tags instead.

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 18:15:51 2014
New Revision: 215019

URL: http://llvm.org/viewvc/llvm-project?rev=215019view=rev
Log:
Revert renaming. Should rename tags instead.

Added:
lldb/branches/release_35/   (props changed)
  - copied from r215018, lldb/branches/release_350/
Removed:
lldb/branches/release_350/

Propchange: lldb/branches/release_35/
--
--- svn:mergeinfo (added)
+++ svn:mergeinfo Wed Aug  6 18:15:51 2014
@@ -0,0 +1,3 @@
+/lldb/branches/apple/python-GIL:156467-162159
+/lldb/branches/iohandler:198360-200250
+/lldb/trunk:214291


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [llvm-tag] r215021 - Renaming to coincide with updated tagging system.

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 18:16:46 2014
New Revision: 215021

URL: http://llvm.org/viewvc/llvm-project?rev=215021view=rev
Log:
Renaming to coincide with updated tagging system.

Added:
llvm/tags/RELEASE_350/
  - copied from r215020, llvm/tags/RELEASE_35/
Removed:
llvm/tags/RELEASE_35/

___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [polly] r215018 - Revert renaming. Should rename tags instead.

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 18:15:48 2014
New Revision: 215018

URL: http://llvm.org/viewvc/llvm-project?rev=215018view=rev
Log:
Revert renaming. Should rename tags instead.

Added:
polly/branches/release_35/
  - copied from r215017, polly/branches/release_350/
Removed:
polly/branches/release_350/

___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [compiler-rt-tag] r215025 - Renaming to coincide with updated tagging system.

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 18:17:00 2014
New Revision: 215025

URL: http://llvm.org/viewvc/llvm-project?rev=215025view=rev
Log:
Renaming to coincide with updated tagging system.

Added:
compiler-rt/tags/RELEASE_350/
  - copied from r215024, compiler-rt/tags/RELEASE_35/
Removed:
compiler-rt/tags/RELEASE_35/

___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [polly] r215028 - Renaming to coincide with updated tagging system.

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 18:17:10 2014
New Revision: 215028

URL: http://llvm.org/viewvc/llvm-project?rev=215028view=rev
Log:
Renaming to coincide with updated tagging system.

Added:
polly/tags/RELEASE_350/
  - copied from r215027, polly/tags/RELEASE_35/
Removed:
polly/tags/RELEASE_35/

___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [llvm-tag] r215033 - Creating release candidate rc2 from release_350 branch

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 18:27:30 2014
New Revision: 215033

URL: http://llvm.org/viewvc/llvm-project?rev=215033view=rev
Log:
Creating release candidate rc2 from release_350 branch

Added:
llvm/tags/RELEASE_350/rc2/   (props changed)
  - copied from r215032, llvm/branches/release_35/

Propchange: llvm/tags/RELEASE_350/rc2/
--
--- svn:ignore (added)
+++ svn:ignore Wed Aug  6 18:27:30 2014
@@ -0,0 +1,24 @@
+Debug
+Release
+Release-Asserts
+mklib
+Makefile.config
+config.log
+config.status
+cvs.out
+autom4te.cache
+configure.out
+LLVM-*
+_distcheckdir
+llvm.spec
+svn-commit.*
+*.patch
+*.patch.raw
+cscope.*
+Debug+Coverage-Asserts
+Release+Coverage-Asserts
+Debug+Coverage
+Release+Coverage
+Debug+Checks
+Debug+Asserts
+Release+Asserts

Propchange: llvm/tags/RELEASE_350/rc2/
--
--- svn:mergeinfo (added)
+++ svn:mergeinfo Wed Aug  6 18:27:30 2014
@@ -0,0 +1,3 @@
+/llvm/branches/Apple/Pertwee:110850,110961
+/llvm/branches/type-system-rewrite:133420-134817
+/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798-213799,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214060,214129,214180,214287,214331,214423,214429,214519


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [polly] r215040 - Creating release candidate rc2 from release_350 branch

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 18:28:05 2014
New Revision: 215040

URL: http://llvm.org/viewvc/llvm-project?rev=215040view=rev
Log:
Creating release candidate rc2 from release_350 branch

Added:
polly/tags/RELEASE_350/rc2/
  - copied from r215039, polly/branches/release_35/

___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [llvm-branch] r215058 - Merging r214481:

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 23:52:45 2014
New Revision: 215058

URL: http://llvm.org/viewvc/llvm-project?rev=215058view=rev
Log:
Merging r214481:

r214481 | hfinkel | 2014-07-31 22:20:41 -0700 (Thu, 31 Jul 2014) | 38 lines

[PowerPC] Generate unaligned vector loads using intrinsics instead of regular 
loads

Altivec vector loads on PowerPC have an interesting property: They always load
from an aligned address (by rounding down the address actually provided if
necessary). In order to generate an actual unaligned load, you can generate two
load instructions, one with the original address, one offset by one vector
length, and use a special permutation to extract the bytes desired.

When this was originally implemented, I generated these two loads using regular
ISD::LOAD nodes, now marked as aligned. Unfortunately, there is a problem with
this:

The alignment of a load does not contribute to its identity, and SDNodes
are uniqued. So, imagine that we have some unaligned load, L1, that is not
aligned. The routine will create two loads, L1(aligned) and (L1+16)(aligned).
Further imagine that there had already existed a load (L1+16)(unaligned) with
the same chain operand as the load L1. When (L1+16)(aligned) is created as part
of the lowering of L1, this load *is* also the (L1+16)(unaligned) node, just
now marked as aligned (because the new alignment overwrites the old). But the
original users of (L1+16)(unaligned) now get the data intended for the
permutation yielding the data for L1, and (L1+16)(unaligned) no longer exists
to get its own permutation-based expansion. This was PR19991.

A second potential problem has to do with the MMOs on these loads, which can be
used by AA during instruction scheduling to break chain-based dependencies. If
the new aligned loads get the MMO from the original unaligned load, this does
not represent the fact that it will load data from below the original address.
Normally, this would not matter, but this load might be combined with another
load pair for a previous vector, and then the dependency on the otherwise-
ignored lower bytes can matter.

To fix both problems, instead of generating the necessary loads using regular
ISD::LOAD instructions, ppc_altivec_lvx intrinsics are used instead. These are
provided with MMOs with a conservative address range.

Unfortunately, I no longer have a failing test case (since PR19991 was
reported, other changes in CodeGen have forced this bug back into hiding it
again). Nevertheless, this should fix the underlying problem.


Modified:
llvm/branches/release_35/   (props changed)
llvm/branches/release_35/lib/CodeGen/SelectionDAG/SelectionDAG.cpp
llvm/branches/release_35/lib/Target/PowerPC/PPCISelLowering.cpp

Propchange: llvm/branches/release_35/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Wed Aug  6 23:52:45 2014
@@ -1,3 +1,3 @@
 /llvm/branches/Apple/Pertwee:110850,110961
 /llvm/branches/type-system-rewrite:133420-134817
-/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798-213799,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214060,214129,214180,214287,214331,214423,214429,214519
+/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798-213799,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214060,214129,214180,214287,214331,214423,214429,214481,214519

Modified: llvm/branches/release_35/lib/CodeGen/SelectionDAG/SelectionDAG.cpp
URL: 
http://llvm.org/viewvc/llvm-project/llvm/branches/release_35/lib/CodeGen/SelectionDAG/SelectionDAG.cpp?rev=215058r1=215057r2=215058view=diff
==
--- llvm/branches/release_35/lib/CodeGen/SelectionDAG/SelectionDAG.cpp 
(original)
+++ llvm/branches/release_35/lib/CodeGen/SelectionDAG/SelectionDAG.cpp Wed Aug  
6 23:52:45 2014
@@ -6263,7 +6263,10 @@ MemSDNode::MemSDNode(unsigned Opc, unsig
   assert(isVolatile() == MMO-isVolatile()  Volatile encoding error!);
   assert(isNonTemporal() == MMO-isNonTemporal() 
  Non-temporal encoding error!);
-  assert(memvt.getStoreSize() == MMO-getSize()  Size mismatch!);
+  // We check here that the size of the memory operand fits within the size of
+  // the MMO. This is because the MMO might indicate only a possible address
+  // range instead of specifying the affected memory addresses precisely.
+  assert(memvt.getStoreSize() = MMO-getSize()  Size mismatch!);
 }
 
 MemSDNode::MemSDNode(unsigned Opc, unsigned Order, DebugLoc dl, SDVTList VTs,
@@ -6273,7 +6276,7 @@ MemSDNode::MemSDNode(unsigned Opc, unsig
   SubclassData = encodeMemSDNodeFlags(0, ISD::UNINDEXED, MMO-isVolatile(),
   MMO-isNonTemporal(), 
MMO-isInvariant());
   assert(isVolatile() 

[llvm-branch-commits] [compiler-rt-tag] r215063 - Remove for retagging.

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 23:55:18 2014
New Revision: 215063

URL: http://llvm.org/viewvc/llvm-project?rev=215063view=rev
Log:
Remove for retagging.

Removed:
compiler-rt/tags/RELEASE_350/rc2/

___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [llvm-tag] r215069 - Creating release candidate rc2 from release_350 branch

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 23:55:52 2014
New Revision: 215069

URL: http://llvm.org/viewvc/llvm-project?rev=215069view=rev
Log:
Creating release candidate rc2 from release_350 branch

Added:
llvm/tags/RELEASE_350/rc2/   (props changed)
  - copied from r215068, llvm/branches/release_35/

Propchange: llvm/tags/RELEASE_350/rc2/
--
--- svn:ignore (added)
+++ svn:ignore Wed Aug  6 23:55:52 2014
@@ -0,0 +1,24 @@
+Debug
+Release
+Release-Asserts
+mklib
+Makefile.config
+config.log
+config.status
+cvs.out
+autom4te.cache
+configure.out
+LLVM-*
+_distcheckdir
+llvm.spec
+svn-commit.*
+*.patch
+*.patch.raw
+cscope.*
+Debug+Coverage-Asserts
+Release+Coverage-Asserts
+Debug+Coverage
+Release+Coverage
+Debug+Checks
+Debug+Asserts
+Release+Asserts

Propchange: llvm/tags/RELEASE_350/rc2/
--
--- svn:mergeinfo (added)
+++ svn:mergeinfo Wed Aug  6 23:55:52 2014
@@ -0,0 +1,3 @@
+/llvm/branches/Apple/Pertwee:110850,110961
+/llvm/branches/type-system-rewrite:133420-134817
+/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798-213799,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214060,214129,214180,214287,214331,214423,214429,214481,214519


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [lldb] r215077 - Creating release candidate rc2 from release_350 branch

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 23:56:39 2014
New Revision: 215077

URL: http://llvm.org/viewvc/llvm-project?rev=215077view=rev
Log:
Creating release candidate rc2 from release_350 branch

Added:
lldb/tags/RELEASE_350/rc2/   (props changed)
  - copied from r215076, lldb/branches/release_35/

Propchange: lldb/tags/RELEASE_350/rc2/
--
--- svn:mergeinfo (added)
+++ svn:mergeinfo Wed Aug  6 23:56:39 2014
@@ -0,0 +1,3 @@
+/lldb/branches/apple/python-GIL:156467-162159
+/lldb/branches/iohandler:198360-200250
+/lldb/trunk:214291


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [polly] r215076 - Creating release candidate rc2 from release_350 branch

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 23:56:33 2014
New Revision: 215076

URL: http://llvm.org/viewvc/llvm-project?rev=215076view=rev
Log:
Creating release candidate rc2 from release_350 branch

Added:
polly/tags/RELEASE_350/rc2/
  - copied from r215075, polly/branches/release_35/

___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [clang-tools-extra-tag] r215075 - Creating release candidate rc2 from release_350 branch

2014-08-06 Thread Bill Wendling
Author: void
Date: Wed Aug  6 23:56:27 2014
New Revision: 215075

URL: http://llvm.org/viewvc/llvm-project?rev=215075view=rev
Log:
Creating release candidate rc2 from release_350 branch

Added:
clang-tools-extra/tags/RELEASE_350/rc2/
  - copied from r215074, clang-tools-extra/branches/release_35/

___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [lldb] r215425 - Fix lldb build for 3.5 release. Patcy by Sylvestre Ladru.

2014-08-11 Thread Bill Wendling
Author: void
Date: Tue Aug 12 00:32:50 2014
New Revision: 215425

URL: http://llvm.org/viewvc/llvm-project?rev=215425view=rev
Log:
Fix lldb build for 3.5 release. Patcy by Sylvestre Ladru.

Modified:
lldb/branches/release_35/source/Expression/ClangExpressionParser.cpp

Modified: lldb/branches/release_35/source/Expression/ClangExpressionParser.cpp
URL: 
http://llvm.org/viewvc/llvm-project/lldb/branches/release_35/source/Expression/ClangExpressionParser.cpp?rev=215425r1=215424r2=215425view=diff
==
--- lldb/branches/release_35/source/Expression/ClangExpressionParser.cpp 
(original)
+++ lldb/branches/release_35/source/Expression/ClangExpressionParser.cpp Tue 
Aug 12 00:32:50 2014
@@ -231,9 +231,11 @@ ClangExpressionParser::ClangExpressionPa
 
 // Disable some warnings.
 
m_compiler-getDiagnostics().setSeverityForGroup(clang::diag::Flavor::WarningOrError,
-unused-value, clang::diag::Severity::Ignored, SourceLocation());
+diag::Flavor::Remark, unused-value, clang::diag::Severity::Ignored,
+SourceLocation());
 
m_compiler-getDiagnostics().setSeverityForGroup(clang::diag::Flavor::WarningOrError,
-odr, clang::diag::Severity::Ignored, SourceLocation());
+diag::Flavor::Remark, odr, clang::diag::Severity::Ignored,
+SourceLocation());
 
 // Inform the target of the language options
 //


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [cfe-branch] r215427 - Merging r215229:

2014-08-11 Thread Bill Wendling
Author: void
Date: Tue Aug 12 00:38:53 2014
New Revision: 215427

URL: http://llvm.org/viewvc/llvm-project?rev=215427view=rev
Log:
Merging r215229:

r215229 | sylvestre | 2014-08-08 10:15:13 -0700 (Fri, 08 Aug 2014) | 11 lines

Fix a bug when scan-build is used in a cross-compilation environment with
the --use-cc option.

Instead, we will search in the PATH
For example:
 scan-build --use-cc=arm-none-eabi-gcc -o out make -e

Initially reported as a Debian Bug:
https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=748777




Modified:
cfe/branches/release_35/   (props changed)
cfe/branches/release_35/tools/scan-build/ccc-analyzer

Propchange: cfe/branches/release_35/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Tue Aug 12 00:38:53 2014
@@ -1,4 +1,4 @@
 /cfe/branches/type-system-rewrite:134693-134817
-/cfe/trunk:213609,213611,213613,213741,213834,213840,213902,213912-213913,213993,213998-213999,214008,214050,214060,214119,214208,214222,214369,214390,214471,214734-214735,214777,215046,215245
+/cfe/trunk:213609,213611,213613,213741,213834,213840,213902,213912-213913,213993,213998-213999,214008,214050,214060,214119,214208,214222,214369,214390,214471,214734-214735,214777,215046,215229,215245
 /cfe/trunk/test:170344
 /cfe/trunk/test/SemaTemplate:126920

Modified: cfe/branches/release_35/tools/scan-build/ccc-analyzer
URL: 
http://llvm.org/viewvc/llvm-project/cfe/branches/release_35/tools/scan-build/ccc-analyzer?rev=215427r1=215426r2=215427view=diff
==
--- cfe/branches/release_35/tools/scan-build/ccc-analyzer (original)
+++ cfe/branches/release_35/tools/scan-build/ccc-analyzer Tue Aug 12 00:38:53 
2014
@@ -25,6 +25,17 @@ use Text::ParseWords;
 # Compiler command setup.
 
##===--===##
 
+# Search in the PATH if the compiler exists
+sub SearchInPath {
+my $file = shift;
+foreach my $dir (split (':', $ENV{PATH})) {
+if (-x $dir/$file) {
+return 1;
+}
+}
+return 0;
+}
+
 my $Compiler;
 my $Clang;
 my $DefaultCCompiler;
@@ -41,7 +52,7 @@ if (`uname -a` =~ m/Darwin/) {
 
 if ($FindBin::Script =~ /c\+\+-analyzer/) {
   $Compiler = $ENV{'CCC_CXX'};
-  if (!defined $Compiler || ! -x $Compiler) { $Compiler = $DefaultCXXCompiler; 
}
+  if (!defined $Compiler || (! -x $Compiler  ! SearchInPath($Compiler))) { 
$Compiler = $DefaultCXXCompiler; }
 
   $Clang = $ENV{'CLANG_CXX'};
   if (!defined $Clang || ! -x $Clang) { $Clang = 'clang++'; }
@@ -50,7 +61,7 @@ if ($FindBin::Script =~ /c\+\+-analyzer/
 }
 else {
   $Compiler = $ENV{'CCC_CC'};
-  if (!defined $Compiler || ! -x $Compiler) { $Compiler = $DefaultCCompiler; }
+  if (!defined $Compiler || (! -x $Compiler  ! SearchInPath($Compiler))) { 
$Compiler = $DefaultCCompiler; }
 
   $Clang = $ENV{'CLANG'};
   if (!defined $Clang || ! -x $Clang) { $Clang = 'clang'; }


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [llvm-branch] r215430 - Merging r214679:

2014-08-11 Thread Bill Wendling
Author: void
Date: Tue Aug 12 00:41:35 2014
New Revision: 215430

URL: http://llvm.org/viewvc/llvm-project?rev=215430view=rev
Log:
Merging r214679:

r214679 | chandlerc | 2014-08-03 17:54:28 -0700 (Sun, 03 Aug 2014) | 10 lines

[x86] Fix the test case added in r214670 and tweaked in r214674 further.

Fundamentally, there isn't a really portable way to test the constant
pool contents. Instead, pin this test to the bare-metal triple. This
also makes it a 64-bit triple which allows us to only match a single
constant pool rather than two. It can also just hard code the '.' prefix
as the format should be stable now that it has a fixed triple. Finally,
I've switched it to use CHECK-NEXT to be more precise in the instruction
sequence expected and to use variables rather than hard coding decisions
by the register allocator.


Modified:
llvm/branches/release_35/   (props changed)
llvm/branches/release_35/test/CodeGen/X86/vec_fabs.ll

Propchange: llvm/branches/release_35/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Tue Aug 12 00:41:35 2014
@@ -1,3 +1,3 @@
 /llvm/branches/Apple/Pertwee:110850,110961
 /llvm/branches/type-system-rewrite:133420-134817
-/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798-213799,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214060,214129,214180,214287,214331,214423,214429,214519,214670,214674
+/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798-213799,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214060,214129,214180,214287,214331,214423,214429,214519,214670,214674,214679

Modified: llvm/branches/release_35/test/CodeGen/X86/vec_fabs.ll
URL: 
http://llvm.org/viewvc/llvm-project/llvm/branches/release_35/test/CodeGen/X86/vec_fabs.ll?rev=215430r1=215429r2=215430view=diff
==
--- llvm/branches/release_35/test/CodeGen/X86/vec_fabs.ll (original)
+++ llvm/branches/release_35/test/CodeGen/X86/vec_fabs.ll Tue Aug 12 00:41:35 
2014
@@ -1,4 +1,4 @@
-; RUN: llc  %s -march=x86 -mattr=+avx | FileCheck %s
+; RUN: llc  %s -mtriple=x86_64-unknown-unknown -mcpu=corei7-avx | FileCheck %s
 
 
 define 2 x double @fabs_v2f64(2 x double %p)
@@ -39,18 +39,16 @@ declare 8 x float @llvm.fabs.v8f32(8
 
 ; PR20354: when generating code for a vector fabs op,
 ; make sure the correct mask is used for all vector elements.
-; CHECK-LABEL: LCPI4_0
-; CHECK: .long 2147483648
-; CHECK: .long 2147483648
-; CHECK-LABEL: LCPI4_1 
-; CHECK: .long 2147483647
-; CHECK: .long 2147483647
-; CHECK-LABEL: fabs_v2f32_1
-; CHECK: vmovdqa {{.*}}LCPI4_0, %xmm0
-; CHECK: vpand   {{.*}}LCPI4_1, %xmm0, %xmm0
-; CHECK: vmovd   %xmm0, %eax
-; CHECK: vpextrd $1, %xmm0, %edx
-define i64 @fabs_v2f32_1() {
+; CHECK-LABEL: .LCPI4_0:
+; CHECK-NEXT:.long 2147483647
+; CHECK-NEXT:.long 2147483647
+define i64 @fabs_v2f32(2 x float %v) {
+; CHECK-LABEL: fabs_v2f32:
+; CHECK: movabsq $-9223372034707292160, %[[R:r[^ ]+]]
+; CHECK-NEXT:vmovq %[[R]], %[[X:xmm[0-9]+]]
+; CHECK-NEXT:vandps   {{.*}}.LCPI4_0{{.*}}, %[[X]], %[[X]]
+; CHECK-NEXT:vmovq   %[[X]], %rax
+; CHECK-NEXT:retq
   %highbits = bitcast i64 9223372039002259456 to 2 x float ; 
0x8000__8000_
   %fabs = call 2 x float @llvm.fabs.v2f32(2 x float %highbits)
   %ret = bitcast 2 x float %fabs to i64


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [cfe-branch] r215876 - Merging r215807:

2014-08-17 Thread Bill Wendling
Author: void
Date: Mon Aug 18 00:15:18 2014
New Revision: 215876

URL: http://llvm.org/viewvc/llvm-project?rev=215876view=rev
Log:
Merging r215807:

r215807 | nicholas | 2014-08-15 19:11:54 -0700 (Fri, 15 Aug 2014) | 2 lines

Try indenting to put all the text inside the block.



Modified:
cfe/branches/release_35/   (props changed)
cfe/branches/release_35/docs/AttributeReference.rst

Propchange: cfe/branches/release_35/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Aug 18 00:15:18 2014
@@ -1,4 +1,4 @@
 /cfe/branches/type-system-rewrite:134693-134817
-/cfe/trunk:213609,213611,213613,213741,213834,213840,213902,213912-213913,213993,213998-213999,214008,214050,214060,214119,214208,214222,214369,214390,214471,214734-214735,214777,215046,215229,215245,215806
+/cfe/trunk:213609,213611,213613,213741,213834,213840,213902,213912-213913,213993,213998-213999,214008,214050,214060,214119,214208,214222,214369,214390,214471,214734-214735,214777,215046,215229,215245,215806-215807
 /cfe/trunk/test:170344
 /cfe/trunk/test/SemaTemplate:126920

Modified: cfe/branches/release_35/docs/AttributeReference.rst
URL: 
http://llvm.org/viewvc/llvm-project/cfe/branches/release_35/docs/AttributeReference.rst?rev=215876r1=215875r2=215876view=diff
==
--- cfe/branches/release_35/docs/AttributeReference.rst (original)
+++ cfe/branches/release_35/docs/AttributeReference.rst Mon Aug 18 00:15:18 2014
@@ -237,9 +237,9 @@ enable_if
X,,,
 
 .. Note:: Some features of this attribute are experimental. The meaning of
-multiple enable_if attributes on a single declaration is subject to change in
-a future version of clang. Also, the ABI is not standardized and the mangled
-name produced may change. To avoid that, use asm labels.
+  multiple enable_if attributes on a single declaration is subject to change in
+  a future version of clang. Also, the ABI is not standardized and the mangled
+  name produced may change. To avoid that, use asm labels.
 
 The ``enable_if`` attribute can be placed on function declarations to control
 which overload is selected based on the values of the function's arguments.


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [llvm-branch] r215874 - Merging r215806:

2014-08-17 Thread Bill Wendling
Author: void
Date: Mon Aug 18 00:14:39 2014
New Revision: 215874

URL: http://llvm.org/viewvc/llvm-project?rev=215874view=rev
Log:
Merging r215806:


Modified:
llvm/branches/release_35/   (props changed)

Propchange: llvm/branches/release_35/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Aug 18 00:14:39 2014
@@ -1,3 +1,3 @@
 /llvm/branches/Apple/Pertwee:110850,110961
 /llvm/branches/type-system-rewrite:133420-134817
-/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798-213799,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214060,214129,214180,214287,214331,214423,214429,214519,214670,214674,214679
+/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798-213799,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214060,214129,214180,214287,214331,214423,214429,214519,214670,214674,214679,215806


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [llvm-branch] r215879 - Merging r215711:

2014-08-17 Thread Bill Wendling
Author: void
Date: Mon Aug 18 00:16:58 2014
New Revision: 215879

URL: http://llvm.org/viewvc/llvm-project?rev=215879view=rev
Log:
Merging r215711:

r215711 | wschmidt | 2014-08-15 06:51:57 -0700 (Fri, 15 Aug 2014) | 8 lines

[PPC64] Add test case for r215685.

I had deferred adding this test case until I could get it down to a
reasonable size.  That's done now.

Thanks,
Bill



Added:
llvm/branches/release_35/test/CodeGen/PowerPC/toc-load-sched-bug.ll
  - copied unchanged from r215711, 
llvm/trunk/test/CodeGen/PowerPC/toc-load-sched-bug.ll
Modified:
llvm/branches/release_35/   (props changed)

Propchange: llvm/branches/release_35/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Aug 18 00:16:58 2014
@@ -1,3 +1,3 @@
 /llvm/branches/Apple/Pertwee:110850,110961
 /llvm/branches/type-system-rewrite:133420-134817
-/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798-213799,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214060,214129,214180,214287,214331,214423,214429,214519,214670,214674,214679,215685,215806
+/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798-213799,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214060,214129,214180,214287,214331,214423,214429,214519,214670,214674,214679,215685,215711,215806


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [cfe-branch] r215881 - Merging r215609:

2014-08-17 Thread Bill Wendling
Author: void
Date: Mon Aug 18 00:18:35 2014
New Revision: 215881

URL: http://llvm.org/viewvc/llvm-project?rev=215881view=rev
Log:
Merging r215609:

r215609 | majnemer | 2014-08-13 17:49:23 -0700 (Wed, 13 Aug 2014) | 3 lines

Sema: Permit nullptr template args in MSVC compat mode

This fixes a regression I caused back in r211766.


Modified:
cfe/branches/release_35/   (props changed)
cfe/branches/release_35/lib/Sema/SemaTemplate.cpp
cfe/branches/release_35/test/Parser/MicrosoftExtensions.cpp

Propchange: cfe/branches/release_35/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Mon Aug 18 00:18:35 2014
@@ -1,4 +1,4 @@
 /cfe/branches/type-system-rewrite:134693-134817
-/cfe/trunk:213609,213611,213613,213741,213834,213840,213902,213912-213913,213993,213998-213999,214008,214050,214060,214119,214208,214222,214369,214390,214471,214734-214735,214777,215046,215229,215245,215618,215806-215808
+/cfe/trunk:213609,213611,213613,213741,213834,213840,213902,213912-213913,213993,213998-213999,214008,214050,214060,214119,214208,214222,214369,214390,214471,214734-214735,214777,215046,215229,215245,215609,215618,215806-215808
 /cfe/trunk/test:170344
 /cfe/trunk/test/SemaTemplate:126920

Modified: cfe/branches/release_35/lib/Sema/SemaTemplate.cpp
URL: 
http://llvm.org/viewvc/llvm-project/cfe/branches/release_35/lib/Sema/SemaTemplate.cpp?rev=215881r1=215880r2=215881view=diff
==
--- cfe/branches/release_35/lib/Sema/SemaTemplate.cpp (original)
+++ cfe/branches/release_35/lib/Sema/SemaTemplate.cpp Mon Aug 18 00:18:35 2014
@@ -4189,7 +4189,7 @@ isNullPointerValueTemplateArgument(Sema
   if (Arg-isValueDependent() || Arg-isTypeDependent())
 return NPV_NotNullPointer;
   
-  if (!S.getLangOpts().CPlusPlus11 || S.getLangOpts().MSVCCompat)
+  if (!S.getLangOpts().CPlusPlus11)
 return NPV_NotNullPointer;
   
   // Determine whether we have a constant expression.

Modified: cfe/branches/release_35/test/Parser/MicrosoftExtensions.cpp
URL: 
http://llvm.org/viewvc/llvm-project/cfe/branches/release_35/test/Parser/MicrosoftExtensions.cpp?rev=215881r1=215880r2=215881view=diff
==
--- cfe/branches/release_35/test/Parser/MicrosoftExtensions.cpp (original)
+++ cfe/branches/release_35/test/Parser/MicrosoftExtensions.cpp Mon Aug 18 
00:18:35 2014
@@ -118,7 +118,7 @@ typedef COM_CLASS_TEMPLATE_REFstruct_wi
 
 COM_CLASS_TEMPLATE_REFint, __uuidof(struct_with_uuid) good_template_arg;
 
-COM_CLASS_TEMPLATEint, __uuidof(struct_with_uuid) bad_template_arg; // 
expected-error {{non-type template argument of type 'const _GUID' cannot be 
converted to a value of type 'const GUID *' (aka 'const _GUID *')}}
+COM_CLASS_TEMPLATEint, __uuidof(struct_with_uuid) bad_template_arg; // 
expected-error {{non-type template argument of type 'const _GUID' is not a 
constant expression}}
 
 namespace PR16911 {
 struct __declspec(uuid({12345678-1234-1234-1234-1234567890aB})) uuid;
@@ -357,3 +357,7 @@ void *_alloca(int);
 void foo(void) {
   __declspec(align(16)) int *buffer = (int *)_alloca(9);
 }
+
+template int *
+struct NullptrArg {};
+NullptrArgnullptr a;


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [llvm-tag] r216050 - Creating release candidate rc3 from release_350 branch

2014-08-20 Thread Bill Wendling
Author: void
Date: Wed Aug 20 02:41:29 2014
New Revision: 216050

URL: http://llvm.org/viewvc/llvm-project?rev=216050view=rev
Log:
Creating release candidate rc3 from release_350 branch

Added:
llvm/tags/RELEASE_350/rc3/   (props changed)
  - copied from r216049, llvm/branches/release_35/

Propchange: llvm/tags/RELEASE_350/rc3/
--
--- svn:ignore (added)
+++ svn:ignore Wed Aug 20 02:41:29 2014
@@ -0,0 +1,24 @@
+Debug
+Release
+Release-Asserts
+mklib
+Makefile.config
+config.log
+config.status
+cvs.out
+autom4te.cache
+configure.out
+LLVM-*
+_distcheckdir
+llvm.spec
+svn-commit.*
+*.patch
+*.patch.raw
+cscope.*
+Debug+Coverage-Asserts
+Release+Coverage-Asserts
+Debug+Coverage
+Release+Coverage
+Debug+Checks
+Debug+Asserts
+Release+Asserts

Propchange: llvm/tags/RELEASE_350/rc3/
--
--- svn:mergeinfo (added)
+++ svn:mergeinfo Wed Aug 20 02:41:29 2014
@@ -0,0 +1,3 @@
+/llvm/branches/Apple/Pertwee:110850,110961
+/llvm/branches/type-system-rewrite:133420-134817
+/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798-213799,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214060,214129,214180,214287,214331,214423,214429,214519,214670,214674,214679,215685,215711,215806


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [cfe-tag] r216051 - Creating release candidate rc3 from release_350 branch

2014-08-20 Thread Bill Wendling
Author: void
Date: Wed Aug 20 02:41:42 2014
New Revision: 216051

URL: http://llvm.org/viewvc/llvm-project?rev=216051view=rev
Log:
Creating release candidate rc3 from release_350 branch

Added:
cfe/tags/RELEASE_350/rc3/   (props changed)
  - copied from r216050, cfe/branches/release_35/

Propchange: cfe/tags/RELEASE_350/rc3/
--
--- svn:ignore (added)
+++ svn:ignore Wed Aug 20 02:41:42 2014
@@ -0,0 +1,3 @@
+configure.out
+cscope.files
+cscope.out

Propchange: cfe/tags/RELEASE_350/rc3/
--
--- svn:mergeinfo (added)
+++ svn:mergeinfo Wed Aug 20 02:41:42 2014
@@ -0,0 +1,4 @@
+/cfe/branches/type-system-rewrite:134693-134817
+/cfe/trunk:213609,213611,213613,213741,213834,213840,213902,213912-213913,213993,213998-213999,214008,214050,214060,214119,214208,214222,214369,214390,214471,214734-214735,214777,215046,215229,215245,215609,215618,215806-215808
+/cfe/trunk/test:170344
+/cfe/trunk/test/SemaTemplate:126920


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [compiler-rt-tag] r216054 - Creating release candidate rc3 from release_350 branch

2014-08-20 Thread Bill Wendling
Author: void
Date: Wed Aug 20 02:42:12 2014
New Revision: 216054

URL: http://llvm.org/viewvc/llvm-project?rev=216054view=rev
Log:
Creating release candidate rc3 from release_350 branch

Added:
compiler-rt/tags/RELEASE_350/rc3/
  - copied from r216053, compiler-rt/branches/release_35/

___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [polly] r216059 - Creating release candidate rc3 from release_350 branch

2014-08-20 Thread Bill Wendling
Author: void
Date: Wed Aug 20 02:42:54 2014
New Revision: 216059

URL: http://llvm.org/viewvc/llvm-project?rev=216059view=rev
Log:
Creating release candidate rc3 from release_350 branch

Added:
polly/tags/RELEASE_350/rc3/
  - copied from r216058, polly/branches/release_35/

___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [clang-tools-extra-tag] r216058 - Creating release candidate rc3 from release_350 branch

2014-08-20 Thread Bill Wendling
Author: void
Date: Wed Aug 20 02:42:47 2014
New Revision: 216058

URL: http://llvm.org/viewvc/llvm-project?rev=216058view=rev
Log:
Creating release candidate rc3 from release_350 branch

Added:
clang-tools-extra/tags/RELEASE_350/rc3/
  - copied from r216057, clang-tools-extra/branches/release_35/

___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [cfe-tag] r216103 - Creating release candidate rc3 from release_350 branch

2014-08-20 Thread Bill Wendling
Author: void
Date: Wed Aug 20 12:45:25 2014
New Revision: 216103

URL: http://llvm.org/viewvc/llvm-project?rev=216103view=rev
Log:
Creating release candidate rc3 from release_350 branch

Added:
cfe/tags/RELEASE_350/rc3/   (props changed)
  - copied from r216102, cfe/branches/release_35/

Propchange: cfe/tags/RELEASE_350/rc3/
--
--- svn:ignore (added)
+++ svn:ignore Wed Aug 20 12:45:25 2014
@@ -0,0 +1,3 @@
+configure.out
+cscope.files
+cscope.out

Propchange: cfe/tags/RELEASE_350/rc3/
--
--- svn:mergeinfo (added)
+++ svn:mergeinfo Wed Aug 20 12:45:25 2014
@@ -0,0 +1,4 @@
+/cfe/branches/type-system-rewrite:134693-134817
+/cfe/trunk:213609,213611,213613,213741,213834,213840,213902,213912-213913,213993,213998-213999,214008,214050,214060,214119,214208,214222,214369,214390,214471,214734-214735,214777,215046,215229,215245,215609,215618,215806-215808
+/cfe/trunk/test:170344
+/cfe/trunk/test/SemaTemplate:126920


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [llvm-tag] r216102 - Creating release candidate rc3 from release_350 branch

2014-08-20 Thread Bill Wendling
Author: void
Date: Wed Aug 20 12:45:18 2014
New Revision: 216102

URL: http://llvm.org/viewvc/llvm-project?rev=216102view=rev
Log:
Creating release candidate rc3 from release_350 branch

Added:
llvm/tags/RELEASE_350/rc3/   (props changed)
  - copied from r216101, llvm/branches/release_35/

Propchange: llvm/tags/RELEASE_350/rc3/
--
--- svn:ignore (added)
+++ svn:ignore Wed Aug 20 12:45:18 2014
@@ -0,0 +1,24 @@
+Debug
+Release
+Release-Asserts
+mklib
+Makefile.config
+config.log
+config.status
+cvs.out
+autom4te.cache
+configure.out
+LLVM-*
+_distcheckdir
+llvm.spec
+svn-commit.*
+*.patch
+*.patch.raw
+cscope.*
+Debug+Coverage-Asserts
+Release+Coverage-Asserts
+Debug+Coverage
+Release+Coverage
+Debug+Checks
+Debug+Asserts
+Release+Asserts

Propchange: llvm/tags/RELEASE_350/rc3/
--
--- svn:mergeinfo (added)
+++ svn:mergeinfo Wed Aug 20 12:45:18 2014
@@ -0,0 +1,3 @@
+/llvm/branches/Apple/Pertwee:110850,110961
+/llvm/branches/type-system-rewrite:133420-134817
+/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798-213799,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214060,214129,214180,214287,214331,214423,214429,214519,214670,214674,214679,215685,215711,215806,216064


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


Re: [llvm-branch-commits] [compiler-rt-branch] r216035 - Merging r215295:

2014-08-26 Thread Bill Wendling
As I mentioned in a previous email, it’s far too late to be patching the 
release branch, especially without telling me first. Please revert this.

-bw

On Aug 19, 2014, at 4:30 PM, Renato Golin renato.go...@linaro.org wrote:

 Author: rengolin
 Date: Tue Aug 19 18:30:32 2014
 New Revision: 216035
 
 URL: http://llvm.org/viewvc/llvm-project?rev=216035view=rev
 Log:
 Merging r215295:
 
 r215295 | compnerd | 2014-08-09 21:17:37 +0100 (Sat, 09 Aug 2014) | 10 lines
 
 builtins: correct __umodsi3, __udivsi3 on ARM
 
 When building the builtins for a modern CPU (idiv support), __umodsi3 was
 completely incorrect as it would behave as __udivmosi3, which takes a tertiary
 parameter which is a pointer.
 
 __udivsi3 was also incorrect, returning the remainder in r1.  Although this
 would not result in any crash or invalid behaviour as r1 is a caller saved
 register in AAPCS, this is unnecessary.  Simply perform the division ignoring
 the remainder.
 
 
 Modified:
compiler-rt/branches/release_35/lib/builtins/arm/udivsi3.S
compiler-rt/branches/release_35/lib/builtins/arm/umodsi3.S
 
 Modified: compiler-rt/branches/release_35/lib/builtins/arm/udivsi3.S
 URL: 
 http://llvm.org/viewvc/llvm-project/compiler-rt/branches/release_35/lib/builtins/arm/udivsi3.S?rev=216035r1=216034r2=216035view=diff
 ==
 --- compiler-rt/branches/release_35/lib/builtins/arm/udivsi3.S (original)
 +++ compiler-rt/branches/release_35/lib/builtins/arm/udivsi3.S Tue Aug 19 
 18:30:32 2014
 @@ -35,9 +35,7 @@ DEFINE_COMPILERRT_FUNCTION(__udivsi3)
 #if __ARM_ARCH_EXT_IDIV__
   tst r1, r1
   beq LOCAL_LABEL(divby0)
 - mov r3, r0
 - udivr0, r3, r1
 - mls r1, r0, r1, r3
 + udivr0, r0, r1
   bx  lr
 #else
   cmp r1, #1
 
 Modified: compiler-rt/branches/release_35/lib/builtins/arm/umodsi3.S
 URL: 
 http://llvm.org/viewvc/llvm-project/compiler-rt/branches/release_35/lib/builtins/arm/umodsi3.S?rev=216035r1=216034r2=216035view=diff
 ==
 --- compiler-rt/branches/release_35/lib/builtins/arm/umodsi3.S (original)
 +++ compiler-rt/branches/release_35/lib/builtins/arm/umodsi3.S Tue Aug 19 
 18:30:32 2014
 @@ -33,10 +33,8 @@ DEFINE_COMPILERRT_FUNCTION(__umodsi3)
 #if __ARM_ARCH_EXT_IDIV__
   tst r1, r1
   beq LOCAL_LABEL(divby0)
 - mov r3, r0
 - udivr0, r3, r1
 - mls r1, r0, r1, r3
 - str r1, [r2]
 + udivr2, r0, r1
 + mls r0, r2, r1, r0
   bx  lr
 #else
   cmp r1, #1
 
 
 ___
 llvm-branch-commits mailing list
 llvm-branch-commits@cs.uiuc.edu
 http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


Re: [llvm-branch-commits] [cfe-branch] r214823 - Merging r214801:

2014-08-26 Thread Bill Wendling
Okay. Thanks for this. I didn’t realize that these were old emails. Sorry for 
freaking out.

-bw

On Aug 26, 2014, at 4:36 PM, Bill Schmidt wschm...@linux.vnet.ibm.com wrote:

 Hi Bill,
 
 I forgot to CC you when I just responded on-list, but it might sit in a
 moderator queue like all these others did, so here is what I wrote:
 
Hi Bill,
 
These were committed back on August 4th.  I followed your
instructions to use the merge tool, but I didn't have
write-authority to the branch-commits list so all the
notifications sat in a queue waiting for verification from a
moderator.  I have to assume that this finally happened...
 
So anyway, nothing untoward here.  These changes were from
several weeks ago.
 
 Thanks,
 Bill
 
 On Tue, 2014-08-26 at 15:31 -0700, Bill Wendling wrote:
 Um…What the hell is this? It’s far too late to be applying things to the 
 branch, especially without my approval
 
 -bw
 
 On Aug 4, 2014, at 4:48 PM, Bill Schmidt wschm...@linux.vnet.ibm.com wrote:
 
 Author: wschmidt
 Date: Mon Aug  4 18:48:10 2014
 New Revision: 214823
 
 URL: http://llvm.org/viewvc/llvm-project?rev=214823view=rev
 Log:
 Merging r214801:
 
 r214801 | wschmidt | 2014-08-04 18:21:26 -0500 (Mon, 04 Aug 2014) | 19 lines
 
 [PPC64LE] Fix wrong IR for vec_sld and vec_vsldoi
 
 My original LE implementation of the vsldoi instruction, with its
 altivec.h interfaces vec_sld and vec_vsldoi, produces incorrect
 shufflevector operations in the LLVM IR.  Correct code is generated
 because the back end handles the incorrect shufflevector in a
 consistent manner.
 
 This patch and a companion patch for LLVM correct this problem by
 removing the fixup from altivec.h and the corresponding fixup from the
 PowerPC back end.  Several test cases are also modified to reflect the
 now-correct LLVM IR.
 
 The vec_sums and vec_vsumsws interfaces in altivec.h are also fixed,
 because they used vec_perm calls intended to be recognized as vsldoi
 instructions.  These vec_perm calls are now replaced with code that
 more clearly shows the intent of the transformation.
 
 
 
 
 Modified:
   cfe/branches/release_35/lib/Headers/altivec.h
   cfe/branches/release_35/test/CodeGen/builtins-ppc-altivec.c
 
 Modified: cfe/branches/release_35/lib/Headers/altivec.h
 URL: 
 http://llvm.org/viewvc/llvm-project/cfe/branches/release_35/lib/Headers/altivec.h?rev=214823r1=214822r2=214823view=diff
 ==
 --- cfe/branches/release_35/lib/Headers/altivec.h (original)
 +++ cfe/branches/release_35/lib/Headers/altivec.h Mon Aug  4 18:48:10 2014
 @@ -5224,113 +5224,65 @@ vec_vslw(vector unsigned int __a, vector
 static vector signed char __ATTRS_o_ai
 vec_sld(vector signed char __a, vector signed char __b, unsigned char __c)
 {
 -#ifdef __LITTLE_ENDIAN__
 -  return vec_perm(__a, __b, (vector unsigned char)
 -(__c,   __c-1, __c-2, __c-3, __c-4, __c-5, __c-6, __c-7,
 - __c-8, __c-9, __c-10, __c-11, __c-12, __c-13, __c-14, __c-15));
 -#else
  return vec_perm(__a, __b, (vector unsigned char)
(__c,   __c+1, __c+2,  __c+3,  __c+4,  __c+5,  __c+6,  __c+7,
 __c+8, __c+9, __c+10, __c+11, __c+12, __c+13, __c+14, __c+15));
 -#endif
 }
 
 static vector unsigned char __ATTRS_o_ai
 vec_sld(vector unsigned char __a, vector unsigned char __b, unsigned char 
 __c)
 {
 -#ifdef __LITTLE_ENDIAN__
 -  return vec_perm(__a, __b, (vector unsigned char)
 -(__c,   __c-1, __c-2, __c-3, __c-4, __c-5, __c-6, __c-7,
 - __c-8, __c-9, __c-10, __c-11, __c-12, __c-13, __c-14, __c-15));
 -#else
  return vec_perm(__a, __b, (vector unsigned char)
(__c,   __c+1, __c+2,  __c+3,  __c+4,  __c+5,  __c+6,  __c+7,
 __c+8, __c+9, __c+10, __c+11, __c+12, __c+13, __c+14, __c+15));
 -#endif
 }
 
 static vector short __ATTRS_o_ai
 vec_sld(vector short __a, vector short __b, unsigned char __c)
 {
 -#ifdef __LITTLE_ENDIAN__
 -  return vec_perm(__a, __b, (vector unsigned char)
 -(__c,   __c-1, __c-2, __c-3, __c-4, __c-5, __c-6, __c-7,
 - __c-8, __c-9, __c-10, __c-11, __c-12, __c-13, __c-14, __c-15));
 -#else
  return vec_perm(__a, __b, (vector unsigned char)
(__c,   __c+1, __c+2,  __c+3,  __c+4,  __c+5,  __c+6,  __c+7,
 __c+8, __c+9, __c+10, __c+11, __c+12, __c+13, __c+14, __c+15));
 -#endif
 }
 
 static vector unsigned short __ATTRS_o_ai
 vec_sld(vector unsigned short __a, vector unsigned short __b, unsigned char 
 __c)
 {
 -#ifdef __LITTLE_ENDIAN__
 -  return vec_perm(__a, __b, (vector unsigned char)
 -(__c,   __c-1, __c-2, __c-3, __c-4, __c-5, __c-6, __c-7,
 - __c-8, __c-9, __c-10, __c-11, __c-12, __c-13, __c-14, __c-15));
 -#else
  return vec_perm(__a, __b, (vector unsigned char)
(__c,   __c+1, __c+2,  __c+3,  __c+4,  __c+5,  __c+6,  __c+7,
 __c+8, __c+9, __c+10, __c+11, __c

[llvm-branch-commits] [llvm-branch] r216762 - Include blurb about Likely. By Josh Klontz.

2014-08-29 Thread Bill Wendling
Author: void
Date: Fri Aug 29 15:00:59 2014
New Revision: 216762

URL: http://llvm.org/viewvc/llvm-project?rev=216762view=rev
Log:
Include blurb about Likely. By Josh Klontz.

Modified:
llvm/branches/release_35/   (props changed)
llvm/branches/release_35/docs/ReleaseNotes.rst

Propchange: llvm/branches/release_35/
--
--- svn:mergeinfo (original)
+++ svn:mergeinfo Fri Aug 29 15:00:59 2014
@@ -1,3 +1,3 @@
 /llvm/branches/Apple/Pertwee:110850,110961
 /llvm/branches/type-system-rewrite:133420-134817
-/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798-213799,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214060,214129,214180,214287,214331,214423,214429,214519,214670,214674,214679,215685,215711,215806,216064
+/llvm/trunk:155241,213653,213665,213726,213749,213773,213793,213798-213799,213815,213847,213880,213883-213884,213894-213896,213899,213915,213966,213999,214060,214129,214180,214287,214331,214423,214429,214519,214670,214674,214679,215685,215711,215806,216064,216531

Modified: llvm/branches/release_35/docs/ReleaseNotes.rst
URL: 
http://llvm.org/viewvc/llvm-project/llvm/branches/release_35/docs/ReleaseNotes.rst?rev=216762r1=216761r2=216762view=diff
==
--- llvm/branches/release_35/docs/ReleaseNotes.rst (original)
+++ llvm/branches/release_35/docs/ReleaseNotes.rst Fri Aug 29 15:00:59 2014
@@ -305,6 +305,21 @@ which ensure vector-friendly data layout
 representation of the program. The project uses the LLVM infrastructure for
 optimization and code generation.
 
+Likely
+--
+
+`Likely http://www.liblikely.org`_ is an embeddable just-in-time Lisp for
+image recognition and heterogenous architectures. Algorithms are just-in-time
+compiled using LLVM’s MCJIT infrastructure to execute on single or
+multi-threaded CPUs and potentially OpenCL SPIR or CUDA enabled GPUs. Likely
+exploits the observation that while image processing and statistical learning
+kernels must be written generically to handle any matrix datatype, at runtime
+they tend to be executed repeatedly on the same type. Likely also seeks to
+explore new optimizations for statistical learning algorithms by moving them
+from an offline model generation step to a compile-time simplification of a
+function (the learning algorithm) with constant arguments (the training set).
+
+
 Additional Information
 ==
 


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [cfe-tag] r216957 - Creating release candidate final from release_350 branch

2014-09-02 Thread Bill Wendling
Author: void
Date: Tue Sep  2 16:34:49 2014
New Revision: 216957

URL: http://llvm.org/viewvc/llvm-project?rev=216957view=rev
Log:
Creating release candidate final from release_350 branch

Added:
cfe/tags/RELEASE_350/final/   (props changed)
  - copied from r216956, cfe/branches/release_35/

Propchange: cfe/tags/RELEASE_350/final/
--
--- svn:ignore (added)
+++ svn:ignore Tue Sep  2 16:34:49 2014
@@ -0,0 +1,3 @@
+configure.out
+cscope.files
+cscope.out

Propchange: cfe/tags/RELEASE_350/final/
--
--- svn:mergeinfo (added)
+++ svn:mergeinfo Tue Sep  2 16:34:49 2014
@@ -0,0 +1,4 @@
+/cfe/branches/type-system-rewrite:134693-134817
+/cfe/trunk:213609,213611,213613,213741,213834,213840,213902,213912-213913,213993,213998-213999,214008,214050,214060,214119,214208,214222,214369,214390,214471,214734-214735,214777,215046,215229,215245,215609,215618,215806-215808,216531,216572
+/cfe/trunk/test:170344
+/cfe/trunk/test/SemaTemplate:126920


___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


[llvm-branch-commits] [compiler-rt-tag] r216960 - Creating release candidate final from release_350 branch

2014-09-02 Thread Bill Wendling
Author: void
Date: Tue Sep  2 16:35:08 2014
New Revision: 216960

URL: http://llvm.org/viewvc/llvm-project?rev=216960view=rev
Log:
Creating release candidate final from release_350 branch

Added:
compiler-rt/tags/RELEASE_350/final/
  - copied from r216959, compiler-rt/branches/release_35/

___
llvm-branch-commits mailing list
llvm-branch-commits@cs.uiuc.edu
http://lists.cs.uiuc.edu/mailman/listinfo/llvm-branch-commits


<    5   6   7   8   9   10
--- cfe/branches/release_35/lib/Sema/TreeTransform.h (original)
+++ cfe/branches/release_35/lib/Sema/TreeTransform.h Mon Aug  4 13:37:31 2014
@@ -344,7 +344,7 @@ public:
   /// TransformExpr or TransformExprs.
   ///
   /// \returns the transformed initializer.
-  ExprResult TransformInitializer(Expr *Init, bool CXXDirectInit);
+  ExprResult TransformInitializer(Expr *Init, bool NotCopyInit);
 
   /// \brief Transform the given list of expressions.
   ///
@@ -2858,7 +2858,7 @@ ExprResult TreeTransformDerived::Trans
 
 templatetypename Derived
 ExprResult TreeTransformDerived::TransformInitializer(Expr *Init,
-bool CXXDirectInit) {
+bool NotCopyInit) {
   // Initializers are instantiated like expressions, except that various outer
   // layers are stripped.
   if (!Init)
@@ -2878,13 +2878,13 @@ ExprResult TreeTransformDerived::Trans
 
   if (CXXStdInitializerListExpr *ILE =
   dyn_castCXXStdInitializerListExpr(Init))
-return TransformInitializer(ILE-getSubExpr(), CXXDirectInit);
+return TransformInitializer(ILE-getSubExpr(), NotCopyInit);
 
   // If this is not a direct-initializer, we only need to reconstruct
   // InitListExprs. Other forms of copy-initialization will be a no-op if
   // the initializer is already the right type.
   CXXConstructExpr *Construct = dyn_castCXXConstructExpr(Init);
-  if (!CXXDirectInit  !(Construct  Construct-isListInitialization()))
+  if (!NotCopyInit  !(Construct  Construct-isListInitialization()))
 return getDerived().TransformExpr(Init);
 
   // Revert value-initialization back to empty parens.
@@ -2907,12 +2907,12 @@ ExprResult TreeTransformDerived::Trans
   // If the 

[llvm-branch-commits] [cfe-branch] r214765 - Merging r214060:

2014-08-04 Thread Bill Wendling
Author: void
Date: Mon Aug  4 14:58:38 2014
New Revision: 214765

URL: http://llvm.org/viewvc/llvm-project?rev=214765view=rev
Log:
Merging r214060:

r214060 | brad | 2014-07-27 18:57:32 -0700 (Sun, 27 Jul 2014) | 2 lines

Add missing override keyword to OpenBSD IsIntegratedAssemblerDefault().



Modified:
cfe/branches/release_35/   (props changed)
cfe/branches/release_35/lib/Driver/ToolChains.h

Propchange: cfe/branches/release_35/
--
@@ -2878,13 +2878,13 @@ ExprResult TreeTransformDerived::Trans
 
-  // If this is not a direct-initializer, we only need to reconstruct
+  // If this is copy-initialization, we only need to reconstruct
   // InitListExprs. Other forms of copy-initialization will be a no-op if
   // the initializer is already the right type.